@@ -3,13 +3,13 @@
 import os
 import re
 
-from flake8.engine import get_style_guide
+from flake8.main import application
 
 import py
 
 import pytest
 
-__version__ = '0.5'
+__version__ = '0.6'
 
 HISTKEY = "flake8/mtimes"
 
@@ -28,6 +28,9 @@ def pytest_addoption(parser):
     parser.addini(
         "flake8-max-line-length",
         help="maximum line length")
+    parser.addini(
+        "flake8-extensions", type="args", default=[".py"],
+        help="a list of file extensions, for example: .py .pyx")
 
 
 def pytest_configure(config):
@@ -35,13 +38,14 @@ def pytest_configure(config):
     if config.option.flake8:
         config._flake8ignore = Ignorer(config.getini("flake8-ignore"))
         config._flake8maxlen = config.getini("flake8-max-line-length")
+        config._flake8exts = config.getini("flake8-extensions")
         config._flake8mtimes = config.cache.get(HISTKEY, {})
 
 
 def pytest_collect_file(path, parent):
     """Filter files down to which ones should be checked."""
     config = parent.config
-    if config.option.flake8 and path.ext == '.py':
+    if config.option.flake8 and path.ext in config._flake8exts:
         flake8ignore = config._flake8ignore(path)
         if flake8ignore is not None:
             return Flake8Item(path, parent, flake8ignore, config._flake8maxlen)
@@ -128,15 +132,22 @@ class Ignorer:
 
 def check_file(path, flake8ignore, maxlength):
     """Run flake8 over a single file, and return the number of failures."""
+    args = []
     if maxlength:
-        flake8_style = get_style_guide(
-            parse_argv=False, paths=['--max-line-length', maxlength])
-    else:
-        flake8_style = get_style_guide(parse_argv=False)
-    options = flake8_style.options
-
-    if options.install_hook:
-        from flake8.hooks import install_hook
-        install_hook()
-
-    return flake8_style.input_file(str(path), expected=flake8ignore)
+        args = ['--max-line-length', maxlength]
+    app = application.Application()
+    app.find_plugins()
+    app.register_plugin_options()
+    app.parse_configuration_and_cli(args)
+    app.options.ignore = flake8ignore
+    app.make_formatter()  # fix this
+    app.make_notifier()
+    app.make_guide()
+    app.make_file_checker_manager()
+    app.run_checks([str(path)])
+    app.formatter.start()
+    app.report_errors()
+    # app.report_statistics()
+    # app.report_benchmarks()
+    app.formatter.stop()
+    return app.result_count
